#
# spec file for package libquicktime
#
# Copyright (c) 2011 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define soname 0

Name:           libquicktime
Version:        1.2.3
Release:        59.4
#to_be_filled_by_service
License:        GPL-2.0+
Summary:        Library for Reading and Writing Quicktime Movie Files
Url:            http://libquicktime.sf.net
Group:          System/Libraries
# http://prdownloads.sourceforge.net/libquicktime/libquicktime-%%{version}.tar.gz
Source0:        http://prdownloads.sourceforge.net/libquicktime/libquicktime-%{version}.tar.gz
Source1:        COPYING
Patch0:         %{name}-1.2.2-dont_disable_deprecated.patch
BuildRequires:  Mesa-devel
BuildRequires:  alsa-devel
BuildRequires:  doxygen
BuildRequires:  gtk2-devel
BuildRequires:  libdv-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libvorbis-devel
BuildRequires:  pkg-config
BuildRequires:  schroedinger-devel
%if 0%{?BUILD_ORIG}
BuildRequires:  libfaac-devel
BuildRequires:  libfaad2-devel
BuildRequires:  libffmpeg_oldabi-devel
BuildRequires:  libmp3lame-devel
BuildRequires:  libx264-devel
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
A library for reading and writing Quicktime movie files, based on and
forked from quicktime4linux.

%package -n %{name}%{soname}


Summary:        Library for Reading and Writing Quicktime Movie Files
Group:          System/Libraries
# Last version with this name was openSUSE 11.4
Provides:       libquicktime = %{version}-%{release}
Obsoletes:      libquicktime <= 1.2.2

%description -n %{name}%{soname}
A library for reading and writing Quicktime movie files, based on and
forked from quicktime4linux.

%package -n libquicktime-devel


Summary:        Library for reading/writing quicktime movie files
Group:          Development/Libraries/C and C++
Requires:       %{name}%{soname} = %{version}

%description -n libquicktime-devel
library for reading/writing quicktime movie files, based on and forked
from quicktime4linux

%package -n libquicktime-tools


Summary:        Libquicktime Tools
Group:          Productivity/Multimedia/Video/Editors and Convertors
Requires:       %{name}%{soname} = %{version}

%description -n libquicktime-tools
Tools for reading/writing quicktime movie files.

%prep
%setup -q
%patch0
# Replace licence with wrong FSF address
cp -v %{S:1} .

%build
%configure \
       --enable-gpl \
       --docdir="%{_docdir}/%{name}-devel" \
       --with-libdv \
       --with-cpuflags=none
make %{?_smp_mflags}

%install
%makeinstall
ln -s lqt "%{buildroot}%{_includedir}/quicktime"
%find_lang libquicktime
find %{buildroot}%{_libdir} -type f -name "*.la" -delete -print

%clean
%{?buildroot:rm -rf %{buildroot}}

%post   -n libquicktime%{soname} -p /sbin/ldconfig

%postun -n libquicktime%{soname} -p /sbin/ldconfig

%files -n libquicktime%{soname} -f libquicktime.lang
%defattr(0644,root,root,0755)
%doc COPYING ChangeLog README TODO
%{_libdir}/libquicktime.so.%{soname}
%{_libdir}/libquicktime.so.%{soname}.*.*
%dir %{_libdir}/libquicktime
%{_libdir}/libquicktime/lqt_audiocodec.so
%{_libdir}/libquicktime/lqt_dv.so
%{_libdir}/libquicktime/lqt_mjpeg.so
%{_libdir}/libquicktime/lqt_png.so
%{_libdir}/libquicktime/lqt_rtjpeg.so
%{_libdir}/libquicktime/lqt_schroedinger.so
%{_libdir}/libquicktime/lqt_videocodec.so
%{_libdir}/libquicktime/lqt_vorbis.so
%if 0%{?BUILD_ORIG}
%{_libdir}/libquicktime/lqt_faac.so
%{_libdir}/libquicktime/lqt_faad2.so
%{_libdir}/libquicktime/lqt_ffmpeg.so
%{_libdir}/libquicktime/lqt_lame.so
%{_libdir}/libquicktime/lqt_x264.so
%endif

%files -n libquicktime-devel
%defattr(0644,root,root,0755)
%doc %{_docdir}/%{name}-devel
%{_includedir}/lqt
%{_includedir}/quicktime
%{_libdir}/libquicktime.so
%{_libdir}/pkgconfig/libquicktime.pc

%files -n libquicktime-tools
%defattr(-,root,root)
%{_bindir}/libquicktime_config
%{_bindir}/lqt_transcode
%{_bindir}/lqtplay
%{_bindir}/lqtremux
%{_bindir}/qt2text
%{_bindir}/qtdechunk
%{_bindir}/qtdump
%{_bindir}/qtinfo
%{_bindir}/qtrechunk
%{_bindir}/qtstreamize
%{_bindir}/qtyuv4toyuv
%doc %{_mandir}/man1/lqtplay.1%{ext_man}

%changelog
* Fri Jul 22 2011 pascal.bleser@opensuse.org
- update to 1.2.3:
  * fixes compilation with newer versions of gtk, ffmpeg, and x264
  * some contributed patches were applied as well
* Sun Jun 26 2011 davejplater@gmail.com
- Removed services
* Fri Jun 24 2011 davejplater@gmail.com
- Replace old COPYING file with new one with correct FSF address.
* Sat Jun 18 2011 reddwarf@opensuse.org
- changed BuildRequires libffmpeg-devel to libffmpeg_oldabi-devel.
  Original fix from Manfred.Tremmel.
* Wed May 18 2011 reddwarf@opensuse.org
- fix baselibs.conf
- allow GTK deprectaed functions
* Thu Apr 28 2011 reddwarf@opensuse.org
- rebased on Packman package. Now it will be shared between both
  repositories.
* Thu Apr 14 2011 toddrme2178@gmail.com
- added 32bit compatibility libraries
* Thu Feb  3 2011 davejplater@gmail.com
- Update to version 1.2.2
- This fixes compilation errors with newer gtk versions and a
  crash in the plugin registry.
* Sun Dec  5 2010 puzel@novell.com
- update to libquicktime-1.2.1
  - fix compilation errors with newer x264 versions
* Thu Dec  2 2010 puzel@novell.com
- update to libquicktime-1.2.0
  - reading and writing of compressed packets for lots of
    codecs
  - cleanup of internals, enhancements, bugfixes
- drop libquicktime-jpeg7.patch (in upstream)
- clean up specfile
* Wed Nov  3 2010 puzel@novell.com
- add libquicktime-jpeg7.patch (bnc#647859)
  - patch by Martin Wilck
* Fri Feb 26 2010 puzel@novell.com
- update to libquicktime-1.1.5
  - encoding of AC3 and H.264 in AVI and some minor fixes
* Fri Jan  8 2010 puzel@novell.com
- update to libquicktime-1.1.4
  - fix avi decoding (broken in 1.1.3)
* Tue Jul 14 2009 puzel@novell.com
- update to libquicktime-1.1.3
  - fix a crash in the v308 codec
* Thu Jun 18 2009 puzel@novell.com
- update to libquicktime-1.1.2
  - dirac video en-/decoding
  - several fixes
- add dirac-devel to BR
* Fri Mar  6 2009 puzel@suse.cz
- update to libquicktime-1.1.1
  * read/write support for timecode tracks
  * support for newer versions of ffmpeg and x264
  * several bugfixes and cleanups
- fix some rpmlint warnings
* Thu Jan 22 2009 crrodriguez@suse.de
- remove "la" files
* Thu Jul 17 2008 puzel@suse.cz
- specfile fixes
  * use configure macro
  * fix htmldir location
  * use %%fdupes only on suse > 10.2
* Tue Jul 15 2008 puzel@suse.cz
- update to 1.0.3
  * dnxhd decoding support
  * double precision audio I/O
  * bugfixes
- add doxygen to BuildRequires
- license changed to LGPL v2 or later
- use RPM_OPT_FLAGS
- minor .spec fixes
* Tue Apr 15 2008 pcerny@suse.cz
- update to 1.0.2
  * removing libquicktime-1.0.0-arrayoverflow.patch
    (merged in upstream)
* Fri Jul 27 2007 maw@suse.de
- Add dont-disable-deprecated.patch
- Use %%fdupes.
* Sat May 12 2007 olh@suse.de
- remove unneded Requires libraw1394-devel
* Wed May  9 2007 pcerny@suse.cz
- minor .spec file changes (%%suse_update_config)
* Fri May  4 2007 pcerny@suse.cz
- update to 1.0.0 which is considered final wrt functionality
- .spec file cleanup
- fixed #218037
* Tue Oct 10 2006 pnemec@suse.cz
- updated to 0.9.10
  Read/Write support for: DVCPRO50 video, OpenDML AVIs, mp4/m4a files
  and Quicktime 7 lpcm audio
  H.264 encoding using x264.
  Improved compatibility with players: Quicktime 7, WMP, Divx player
  see http://libquicktime.sourceforge.net/ for detailed changelog
- minor changes in patch -mjpeg_def_huffman.diff and legal.diff
* Fri Feb 10 2006 bk@suse.de
- fix optimisation (used P4 insns!) and force using RPM_OPT_FLAGS
- fix firewire support (libdv-devel was splitted from libdv)
- remove the forced backout of MMX instructions (obsolete)
- don't include unused libquicktime-cflags.diff
* Sat Feb  4 2006 aj@suse.de
- Reduce BuildRequires.
* Sun Jan 29 2006 aj@suse.de
- Fix BuildRequires.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Sep 15 2005 jw@suse.de
- added support for mjpeg files without
  huffman tables.
* Fri Jul 29 2005 kraxel@suse.de
- fix -devel package dependencies.
* Fri Jul 29 2005 kraxel@suse.de
- add backward compatibility symlink to the new include file location.
* Thu Jul 28 2005 kraxel@suse.de
- update to 0.9.7.
* Mon Apr 18 2005 ro@suse.de
- make it build with gcc-4
* Thu Jan 13 2005 kraxel@suse.de
- update to 0.9.4.
* Tue Aug 17 2004 kraxel@suse.de
- update to 0.9.3.
* Thu Apr 22 2004 kraxel@suse.de
- fix compiler warnings.
* Wed Feb 11 2004 kraxel@suse.de
- update to version 0.9.2.
* Sat Jan 10 2004 adrian@suse.de
- add %%run_dconfig
- -devel package requires glibc-devel now
* Fri Jul 25 2003 kraxel@suse.de
- more cflags fixes, also builds on ppc now ...
* Wed Jul 23 2003 kraxel@suse.de
- play with cflags to make thing build on all archs.
* Mon Jun 16 2003 kukuk@suse.de
- More filelist fixes
* Thu Jun 12 2003 kukuk@suse.de
- Add missing directory to filelist
- *.la file should be mode 644
* Thu May 15 2003 ro@suse.de
- fix build with current libtool
* Mon Aug 12 2002 kraxel@suse.de
- fixed Requires: for the -devel package.
* Wed Jul 31 2002 kraxel@suse.de
- fixed plugin path lookup for lib64.
* Fri Jul 26 2002 adrian@suse.de
- fix neededforbuild
* Mon Jul 15 2002 kraxel@suse.de
- fixed permission issues with fix-libtool script.
* Wed Jul 10 2002 uli@suse.de
- forgot to re-enable %%clean section
* Wed Jul 10 2002 uli@suse.de
- replace "SDL SDL-devel" with "SDL-devel-packages" in neededforbuild
  (fixes libdv detection)
- fixed MMX detection, then disabled it :) (no runtime detection)
- added DISTRIBUTABLE flag to facilitate full-featured rebuild
* Thu Jun 27 2002 kraxel@suse.de
- fixed neededforbuild.
* Mon Jun 24 2002 kraxel@suse.de
- updated to version 0.9.1
* Mon Jun 24 2002 ro@suse.de
- run full autoreconf to also get shared lib on x86_64
* Fri Jun 21 2002 ro@suse.de
- run libtoolize to build also on archs that are
  younger than a decade
* Thu Jun 20 2002 kraxel@suse.de
- fixed build problems by using $RPM_OPT_FLAGS
- disabled divx codec (divx/mpeg4 is patent minefield, sorry folks ...).
* Mon Jun 17 2002 kraxel@suse.de
- initial release.
